@@ -12,10 +12,18 @@ def parse_time(s):
     """
     Like datetime.datetime.strptime(s, "%w %Y/%m/%d %H:%M:%S") but 5x faster.
     """
-    _, date_part, time_part = s.split(' ')
-    year, mon, day = date_part.split('/')
-    hour, minute, sec = time_part.split(':')
-    return datetime.datetime(*map(int, (year, mon, day, hour, minute, sec)))
+    result = None
+
+    if "epoch" in s:
+        epoch_time = float(s.rstrip().split(' ')[1][:-1])
+        result = datetime.datetime.utcfromtimestamp(epoch_time)
+    else:
+        _, date_part, time_part = s.split(' ')
+        year, mon, day = date_part.split('/')
+        hour, minute, sec = time_part.split(':')
+        result = datetime.datetime(*map(int, (year, mon, day, hour, minute, sec)))
+
+    return result
 
 
 def _extract_prop_option(line):
@@ -67,7 +75,7 @@ def _extract_properties(config):
     for line in config.splitlines():
 
         # skip empty & malformed lines
-        if not line or not line[-1:] == ';':
+        if not line or not line[-1:] == ';' and '; #' not in line:
             continue
 
         # strip the trailing ';' and remove any whitespaces on the left side
@@ -208,8 +216,10 @@ class Lease(BaseLease):
 
     def __init__(self, ip, properties, options=None, sets=None):
         super(Lease, self).__init__(ip, properties=properties, options=options, sets=sets)
-
-        self.start = parse_time(properties['starts'])
+        if 'starts' in properties:
+            self.start = parse_time(properties['starts'])
+        else:
+            self.start = None
         if properties.get('ends', 'never') == 'never':
             self.end = None
         else:
@@ -231,9 +241,15 @@ class Lease(BaseLease):
         :return: bool: True if lease is valid
         """
         if self.end is None:
-            return self.start <= datetime.datetime.utcnow()
+            if self.start is not None:
+                return self.start <= datetime.datetime.utcnow()
+            else:
+                return True
         else:
-            return self.start <= datetime.datetime.utcnow() <= self.end
+            if self.start is not None:
+                return self.start <= datetime.datetime.utcnow() <= self.end
+            else:
+                return datetime.datetime.utcnow() <= self.end
 
     def __repr__(self):
         return "<Lease {} for {} ({})>".format(self.ip, self.ethernet, self.hostname)
